File Specifications
===================

This section contains reference documentation for file specifications available
publicly.

.. toctree::
   :hidden:
   
   ripple-specs

.. _edax-file_specification:

EDAX
----

The file specifications for the :ref:`edax <edax-format>` file formats made
available publicly available from EDAX:

- :download:`spc <edax/SPECTRUM-V70.pdf>`
- :download:`spd <edax/SpcMap-spd.file.format.pdf>`
- :download:`ipr <edax/ImageIPR.pdf>`


Ripple (Lispix)
---------------

:ref:`Format description <ripple-file_specification>` for the :ref:`ripple
<ripple-format>` file format.
